@@ -9,7 +9,7 @@ import tdcsm
 
 class coa():
 
-    version = "0.2.0.3"
+    version = "0.2.0.5"
     debug = False
 
     entryvars = {}
@@ -180,7 +180,7 @@ class coa():
     def first_file_that_exists(self, *args):
         for file in args:
             if os.path.isfile(file): return file
-        return 'NONE_FOUND'
+        return ''
 
     def print_dict(self, dict2print={}, lvl=0):
         """Simply prints dictionaries in a more nested/human readable form"""
@@ -289,7 +289,6 @@ class coa():
 # =================== END: HELPER FUNCTIONS ==============================
 
 
-
 # =================== START: PROGRAM BEHAVIOR ==============================
     def close(*args):
         print("GUI Closed")
@@ -419,7 +418,7 @@ class coa():
         print('%s' %argstr)
 
         if name == 'reload_config':
-            self.systems_save2disk()
+            # self.systems_save2disk()
             self.coa.approot      = self.entryvar('approot')
             self.coa.configpath   = os.path.join(self.coa.approot, self.entryvar('config'))
             self.coa.secretpath   = os.path.join(self.coa.approot, self.entryvar('secrets'))
@@ -431,7 +430,7 @@ class coa():
             print('secret: ', self.coa.secretpath)
             print('system: ', self.coa.systemspath)
             print('fileset: ', self.coa.filesetpath)
-            self.systems_readfromdisk()
+            # self.systems_readfromdisk()
             self.button_click('tv_systems_left') # this 'click' will refresh both left and right treeviews
             self.button_click('tv_filesets_left')
         elif name == 'approot':
@@ -441,14 +440,14 @@ class coa():
         elif name == 'prepare_sql':
             self.coa.prepare_sql()
         elif name == 'execute_run':
-            self.systems_save2disk()
+            # self.systems_save2disk()
             self.run_external('execute_run')
             self.upload_get_lastrun_folder()
             #self.coa.execute_run()
         elif name == 'make_customer_files':
             self.coa.make_customer_files()
         elif name == 'upload_to_transcend':
-            self.systems_save2disk()
+            # self.systems_save2disk()
             self.run_external('upload_to_transcend')
             #self.coa.execute_run()
         elif name == 'last_output_folder':
@@ -466,7 +465,7 @@ class coa():
         elif name in ['tv_systems_left','tv_systems_right']:
             if 'selected' in kwargs.keys(): # if item was "selected" kwargs will return which item (else refresh without change)
                 active = 'True'
-                if name[-4:] == 'left':  active = 'False' # left is active, so click is moving to inactive
+                if name[-4:] == 'left':  active = 'False'
                 self.coa.systems[kwargs['selected']]['active'] = active
             d = self.split_dict(self.coa.systems, 'active', default='True', addifmissing=['True','False'])
             self.reload_Tx2('systems', leftlist = d['True'].keys(), rightlist = d['False'].keys())
@@ -585,10 +584,19 @@ class coa():
 
         #-------------- RUN!!!
         self.coa = tdcoa(approot = self.entryvar('approot'), secrets = self.entryvar('secrets'))
-        self.systems_readfromdisk()
+        # self.systems_readfromdisk()
         self.button_click('tv_systems_left') # this 'click' will refresh both left and right treeviews
         self.button_click('tv_filesets_left')
         self.upload_get_lastrun_folder()
+
+        # update our secrets file if default was different than coa.settings value (chicken/egg problem)
+        secrets_from_settings = os.path.join(self.coa.approot, self.coa.settings['secrets'])
+        secrets_from_default = self.entryvars['secrets'].get()
+        if secrets_from_default != secrets_from_settings:
+            self.entryvars['secrets'].set(self.first_file_that_exists(secrets_from_settings, secrets_from_default))
+            self.coa.secrets = self.entryvars['secrets'].get()
+            self.coa.reload_config()
+
         Label(frmHelp, text='Version of tdcsm = %s' %self.coa.version, style='help-bold.TLabel').pack(fill=X, anchor=N)
 
         app.bind('<Escape>', self.close)
